utils::globalVariables(c("POWOcodes", "botregions", "botdivmap", ".env", "year",
                         "year_basionym", "number_synonyms", "status",
                         "setNames", "..count..", "na.omit", ".data"))
